# Plugins

lunchable supports plugins with other, external, services. See below for what's been built already.
If you can't find what you're looking for, consider building it yourself and opening a pull-request.

### [PushLunch](pushlunch.md): Push Notifications via Pushover

### [SplitLunch](splitlunch.md): Splitwise Integration

### [PrimeLunch](primelunch.md): Amazon Transaction Updater
